@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-toolbar-editor.c,v 1.8 2006/05/26 06:45:19 nshmyrev Exp $
+ *  $Id: egg-toolbar-editor.c,v 1.9 2006/10/08 12:35:40 chpe Exp $
  */
 
 #include "config.h"
@@ -78,7 +78,7 @@ egg_toolbar_editor_get_type (void)
 
   if (G_UNLIKELY (type == 0))
     {
-      static const GTypeInfo our_info = {
+      const GTypeInfo our_info = {
 	sizeof (EggToolbarEditorClass),
 	NULL,			/* base_init */
 	NULL,			/* base_finalize */
