@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom-action.c,v 1.2 2005/05/10 08:34:33 marco Exp $
+ *  $Id: ephy-zoom-action.c,v 1.3 2006/10/08 12:35:41 chpe Exp $
  */
 
 #include "config.h"
@@ -69,7 +69,7 @@ ephy_zoom_action_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
 			{
 				sizeof (EphyZoomActionClass),
 				NULL, /* base_init */
