@@ -29,7 +29,9 @@
 #include "ev-window.h"
 
 #include "egg-toolbars-model.h"
+#ifndef HAVE_GTK_RECENT
 #include "egg-recent-model.h"
+#endif
 
 G_BEGIN_DECLS
 
@@ -51,7 +53,9 @@ struct _EvApplication {
 	gchar *toolbars_file;
 	
 	EggToolbarsModel *toolbars_model;
+#ifndef HAVE_GTK_RECENT
 	EggRecentModel  *recent_model;
+#endif
 	
 	gchar *last_chooser_uri;
 };
@@ -71,12 +75,13 @@ gboolean          ev_application_open_window         (EvApplication   *applicati
 						      GError         **error);
 gboolean          ev_application_open_uri            (EvApplication   *application,
 						      const char      *uri,
-						      const char      *page_label,
+						      GHashTable      *args,
 						      guint            timestamp,
 						      GError         **error);
 void              ev_application_open_uri_at_dest    (EvApplication   *application,
 						      const char      *uri,
 						      EvLinkDest      *dest,
+						      EvWindowRunMode  mode,
 						      guint32          timestamp);
 void	          ev_application_open_uri_list       (EvApplication   *application,
 		  			              GSList          *uri_list,
@@ -85,7 +90,9 @@ GList		 *ev_application_get_windows	     (EvApplication   *application);
 
 EggToolbarsModel *ev_application_get_toolbars_model  (EvApplication   *application);
 void              ev_application_save_toolbars_model (EvApplication   *application);
+#ifndef HAVE_GTK_RECENT
 EggRecentModel   *ev_application_get_recent_model    (EvApplication   *application);
+#endif
 void 		  ev_application_set_chooser_uri     (EvApplication   *application, 
 						      const gchar     *uri);
 const gchar	 *ev_application_get_chooser_uri     (EvApplication   *application);
