@@ -305,7 +305,7 @@ print_section_cb (GtkWidget *menuitem, EvSidebarLinks *sidebar)
 		if (!link)
 			return;
 
-		first_page = get_page_from_link (link) + 1;
+		first_page = get_page_from_link (link);
 		if (first_page == -1) {
 			g_object_unref (link);
 			return;
@@ -332,7 +332,7 @@ print_section_cb (GtkWidget *menuitem, EvSidebarLinks *sidebar)
 	
 		window = gtk_widget_get_toplevel (GTK_WIDGET (sidebar));
 		if (EV_IS_WINDOW (window)) {
-#ifdef WITH_GNOME_PRINT
+#ifdef WITH_PRINT
 			ev_window_print_range (EV_WINDOW (window),
 					       first_page, last_page);
 #endif
